import 'package:app_template/app_template.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:general_lib/general_lib.dart';
import 'package:general_lib_flutter/general_lib_flutter_core.dart';
import 'package:play/play.dart';
import 'package:simulate/simulate.dart';

void main() async {
  WidgetsFlutterBinding.ensureInitialized();
  Play.ensureInitialized();
  await Simulate.ensureInitialized();

  SystemChrome.setSystemUIOverlayStyle(
    const SystemUiOverlayStyle(
      statusBarColor: Colors.transparent,
      statusBarIconBrightness: Brightness.light,
      statusBarBrightness: Brightness.dark,
    ),
  );

  runApp(
    AppMain(),
  );
}

class AppMain extends StatelessWidget {
  final ValueNotifier<ThemeMode> themeModeNotifier =
      ValueNotifier(ThemeMode.system);
  AppMain({super.key});

  @override
  Widget build(BuildContext context) {
    return GeneralLibFlutterAppMain(
      theme_notifier: themeModeNotifier,
      builder: (themeMode, lightTheme, darkTheme, Widget? childWidget) {
        return MaterialApp(
          debugShowCheckedModeBanner: false,
          home: Builder(
            builder: (context) {
              Widget child = MaterialApp(
                title: 'Flutter Demo',
                debugShowCheckedModeBanner: false,
                themeMode: themeMode,
                theme: lightTheme,
                darkTheme: darkTheme,
                home: AppTemplate(
                  themeModeNotifier: themeModeNotifier,
                ),
              );
              if (dart.isAndroid == false) {
                return Simulate(
                  isShowFrame: true, // set false for disabled
                  home: child,
                );
              }

              return child;
            },
          ),
        );
      },
    );
  }
}
